==> nim_fluttify-0.1.2.tar.gz: example/lib/src/user_relationship/add_friend.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:demo_widgets/demo_widgets.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';
import 'package:nim_fluttify_example/src/user_relationship/friend_list.screen.dart';

class AddFriendScreen extends StatefulWidget {
  @override
  _AddFriendScreenState createState() => _AddFriendScreenState();
}

class _AddFriendScreenState extends State<AddFriendScreen>
    with AccountTokenMixin {
  VerifyType _verifyType = VerifyType.direct;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('AddFriend')),
      body: Center(
        child: DecoratedColumn(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text('当前账户: $testAccount'),
            Text('待添加账户: $peerAccount'),
            DiscreteSetting(
              head: '添加类型',
              onSelected: (String value) {
                switch (value) {
                  case '直接添加':
                    setState(() {
                      _verifyType = VerifyType.direct;
                    });
                    break;
                  case '申请添加':
                    setState(() {
                      _verifyType = VerifyType.request;
                    });
                    break;
                }
              },
              options: <String>['直接添加', '申请添加'],
            ),
            Text('当前添加类型: $_verifyType'),
            DecoratedRow(
              itemSpacing: kSpaceNormal,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: _handleAddFriend,
                  child: Text('发起添加'),
                ),
                RaisedButton(
                  onPressed: _handleFriendList,
                  child: Text('查看好友列表'),
                ),
              ],
            ),
            if (result != null) Text(result),
          ],
        ),
      ),
    );
  }

  void _handleAddFriend() async {
    clearResult();
    try {
      await Nim.instance.requestAddFriend(
        account: peerAccount,
        verifyType: _verifyType,
      );
      success();
    } catch (e) {
      fail();
    }
  }

  void _handleFriendList() async {
    context.rootNavigator.push(
      MaterialPageRoute(builder: (context) => FriendListScreen()),
    );
  }
}

==> nim_fluttify-0.1.5.tar.gz: example/lib/src/user_relationship/add_friend.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:demo_widgets/demo_widgets.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';
import 'package:nim_fluttify_example/src/user_relationship/friend_list.screen.dart';

class AddFriendScreen extends StatefulWidget {
  @override
  _AddFriendScreenState createState() => _AddFriendScreenState();
}

class _AddFriendScreenState extends State<AddFriendScreen>
    with AccountTokenMixin {
  P2PVerifyType _verifyType = P2PVerifyType.direct;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('AddFriend')),
      body: Center(
        child: DecoratedColumn(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text('当前账户: $testAccount'),
            Text('待添加账户: $peerAccount'),
            DiscreteSetting(
              head: '添加类型',
              onSelected: (String value) {
                switch (value) {
                  case '直接添加':
                    setState(() {
                      _verifyType = P2PVerifyType.direct;
                    });
                    break;
                  case '申请添加':
                    setState(() {
                      _verifyType = P2PVerifyType.request;
                    });
                    break;
                }
              },
              options: <String>['直接添加', '申请添加'],
            ),
            Text('当前添加类型: $_verifyType'),
            DecoratedRow(
              itemSpacing: kSpaceNormal,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: _handleAddFriend,
                  child: Text('发起添加'),
                ),
                RaisedButton(
                  onPressed: _handleFriendList,
                  child: Text('查看好友列表'),
                ),
              ],
            ),
            if (result != null) Text(result),
          ],
        ),
      ),
    );
  }

  void _handleAddFriend() async {
    clearResult();
    try {
      await Nim.instance.requestAddFriend(
        account: peerAccount,
        verifyType: _verifyType,
      );
      success();
    } catch (e) {
      fail();
    }
  }

  void _handleFriendList() async {
    context.rootNavigator.push(
      MaterialPageRoute(builder: (context) => FriendListScreen()),
    );
  }
}
